@@ -6,11 +6,10 @@ use Carp qw/confess cluck/;
 use feature qw/say switch/;
 use Cache::Memcached::Fast;
 use Data::Serializer;
-use Proc::ProcessTable;
 use Data::Dumper;
 
 BEGIN {
-  our $VERSION = '0.1.7';
+  our $VERSION = '0.1.8';
 }
 
 has config_file => ( is => 'rw' );
@@ -181,15 +180,11 @@ sub enq {
         my $last = $1 if $self->last =~ /_(\d+)$/ // 1;
         #checando se last == first e se existe algum valor
         my $first_value = $self->memcached->get($self->first);
-  say "FIRST: " . $self->first;
-  say "FIRST_VALUE: " . Dumper $first_value;
         if( $first_value) {
           $last++;
         }
         $size++;
         my $new_last = $self->qid . $last;
-  say "LAST: $last";
-  say "NEWLAST: $new_last";
         $self->last($new_last);
   
         $self->memcached->set($new_last,$value,0);
@@ -272,6 +267,11 @@ sub show {
 
 sub cleanup {
   my ( $self, ) = @_;
+  $self->load;
+  $self->iterate(sub {
+                  my $index = shift;
+                  $self->memcached->delete($index);
+                });
 }
 
 
@@ -378,14 +378,13 @@ sub _unlock {
   my $lock_idx = $qid . 'LOCKED';
   my $lock_pid = $self->_is_locked($lock_idx);
   if($lock_pid && $lock_pid == $pid){
-say 'DEBUG 1';
     my $rs = $self->memcached->set($lock_idx,0,0);
     confess "Memcached can't write!" if !defined($rs);
     $ok = 1;
   }
   elsif($lock_pid && $lock_pid != $pid){
-say 'DEBUG 2';
     say "Is locked by another process! $lock_pid";
+
   }
   $self->load;
   return $ok;
@@ -399,12 +398,21 @@ say 'DEBUG 2';
 sub _is_locked {
   my ($self,$lock_idx) = @_;
   $lock_idx = 0 if !defined $lock_idx;
+  my $found = 0;
+
 #  confess "Parameter 'lock_idx' is mandatory!" if (!defined($lock_idx) || !$lock_idx);
   if(!defined($lock_idx) || !$lock_idx){
     $lock_idx = $self->qid . 'LOCKED';
   }
   my $lock_pid = $self->memcached->get($lock_idx); #this pid locked the queue!
 #  $lock_pid = 0 if $$ == $lock_pid;
+#  foreach my $p(@{$t->table}){
+#    if($p->pid == $lock_pid){
+#      $found = $p->pid;
+#      last;
+#    }
+#  }
+#  $lock_pid = 0 if !$found;
   return $lock_pid ;
 }
 
@@ -420,7 +428,7 @@ __PACKAGE__->meta->make_immutable;
 
 =head1 VERSION
 
- Version 0.1.7
+ Version 0.1.8
 
  unstable version
 
@@ -441,17 +449,15 @@ some elements:
 
 =over
 
-=item * prefix - This is defined by the 'id_prefix' attribute. Is the real 'name' of queue. 
-Default value is 'CMQID_'. 
+=item * prefix - WARNING! This attribute is deprecated!!! DON'T USE IT! 
+
+=item * index - WARNING! This attribute is deprecated! DON'T USE IT!
 
 =item * name - This is a 'string' that defines a name for your queue;
 
 =item * id - It's a unique identifier for your queue and is defined on the 'id' attribute.
         You can have queues with the same name since you have different ids;
 
-=item * index - Single sequencial number that identifies a position of some element on queue.
-For example: 'CMQID_1_1' This is the first element from queue 'CMQID' with id 1.
-OBS: 'CMQID_1_1' is the same element pointed by 'CMQID_1_first'.
 
 
 =back
